%% PFrameDataInput.m
%  Read model data from input file
%  This file is part of the PFrameMatlab program


%% Ask for input file name, open it and start reading
InputFileName = input('Give input file name : ','s'); %Ask for input file name
fileID = fopen(InputFileName,'r'); %Open input file

tline = fgetl(fileID); %Read a useless row (*PFrameMatlab input file)
tline = fgetl(fileID); %Read a useless row (blank)

%% Read material data
% E: Material modulus of Elasticity
tline = fgetl(fileID); %Read a useless row (*Materials)

NumMaterials=fscanf(fileID, '%i', [1 1]); %Read number of materials
MaterialProperties=zeros(NumMaterials,1); %Initialize MaterialProperties vector

a=fscanf(fileID, '%i %g', [2 NumMaterials]); %Read IDs, E matrix
a=a';
MaterialProperties(:)=a(:,2); %Assign E to MaterialProperties
tline = fgetl(fileID); %Move to next line


%% Read section data
% A: Cross section area
% I: Moment of inertia
tline = fgetl(fileID); %Read a useless row (blank)
tline = fgetl(fileID); %Read a useless row (*Sections)

NumSections=fscanf(fileID, '%i' , [1 1]); %Read number of sections
SectionProperties=zeros(NumSections,2); %Initialize SectionProperties matrix

a=fscanf(fileID, '%i %g %g', [3 NumSections]); %Read IDs, A, I
a=a';
SectionProperties(:)=a(:,2:3); %Assign A, I to SectionProperties
tline = fgetl(fileID); %Move to next line


%% Read nodal data
% x coordinate
% y coordinate
tline = fgetl(fileID); %Read a useless row (blank)
tline = fgetl(fileID); %Read a useless row (*Nodes)

NumNodes=fscanf(fileID, '%i' , [1 1]); %Read number of nodes
NodesCoordinates=zeros(NumNodes,2); %Initialize NodesCoordinates matrix

a=fscanf(fileID, '%i %g %g', [3 NumNodes]); %Read IDs, x, y
a=a';
NodesCoordinates(:)=a(:,2:3); %Assign x, y to NodesCoordinates
tline = fgetl(fileID); %Move to next line


%% Read elemental data (x, y coordinates)
% Start node i
% End node j
% Material group
% Section group
% Element type (1,2,3 or 4)

tline = fgetl(fileID); %Read a useless row (blank)
tline = fgetl(fileID); %Read a useless row (*Elements)

NumElements=fscanf(fileID, '%i' , [1 1]); %Read number of elements
ElementProperties=zeros(NumElements,5); %Initialize ElementProperties matrix

a=fscanf(fileID, '%i %i %i %i %i %i', [6 NumElements]); %Read IDs, Node_i, Node_j, Mat_Group, Sec_Group, Ele_type
a=a';
ElementProperties(:)=a(:,2:6); %Assign Node_i, Node_j, Mat_Group, Sec_Group, Ele_type to ElementProperties
tline = fgetl(fileID); %Move to next line


%% Read constraints
% x constraint
% y constraint
% Rotation constraint

tline = fgetl(fileID); %Read a useless row (blank)
tline = fgetl(fileID); %Read a useless row (*Constraints)

NumConstraints=fscanf(fileID, '%i' , [1 1]); %Read number of constrained nodes
BoundaryConditions=zeros(NumNodes,3); %Initialize BoundaryConditions matrix

if NumConstraints==0; %If no constraints exist, read nothing
else
	for n=1:NumConstraints
        a=fscanf(fileID, '%i %i %i %i', [1 4]); %Read ID, x_constr, y_constr, z_constr
        node_constr=a(1); %Read ID of constrained node
		BoundaryConditions(node_constr,1:3)=a(2:4); %Assign x_constr, y_constr, z_constr to the constrained node
	end
end

tline = fgetl(fileID); %Move to next line


%% Read nodal loads
% x load (force) - global system
% y load (force) - global system
% z load (moment) - global system

tline = fgetl(fileID); %Read a useless row (blank)
tline = fgetl(fileID); %Read a useless row (*Nodal_Loads)

NumNodalLoads=fscanf(fileID, '%i' , [1 1]); %Read number of loaded nodes
NodalLoads=zeros(NumNodes,3); %Initialize NodalLoads matrix

if NumNodalLoads==0; %If no nodal loads exist, read nothing
else
	for n=1:NumNodalLoads
        a=fscanf(fileID, '%i %g %g %g', [1 4]); %Read ID, x_load, y_load, z_load
        node_loaded=a(1); %Read ID of loaded node
		NodalLoads(node_loaded,1:3)=a(2:4); %Assign x_load, y_load, z_load to the loaded node
	end
end


%% Close input file
fclose(fileID);

% End of file -------------------------------------------------------------