%% PFrameDrawModel.m
%  Draws the model on a figure
%  This file is part of the PFrameMatlab program


%% Generate model figure
figure(1) %Initialize figure 1
clf(1) %Clear figure 1

xmin = min(NodesCoordinates(:,1)); %Minimum x-coordinate
xmax = max(NodesCoordinates(:,1)); %Maximum x-coordinate
ymin = min(NodesCoordinates(:,2)); %Minimum y-coordinate
ymax = max(NodesCoordinates(:,2)); %Maximum y-coordinate

axis([xmin-1 xmax+1 ymin-1 ymax+1]); %Initialize axes


%% Draw elements and element properties
for n=1:NumElements; %Scan all elements
	PFrameAssignElementProperties;  %Get properties for n element
    line([x1 x2],[y1 y2],[0 0],'Marker','.','MarkerSize',15,'LineStyle','-','LineWidth',2,'Color',[0 0 0]); %Draw line for n element
    element_id=sprintf('%i',n);
    x_middle=(NodesCoordinates(Node_i,1)+NodesCoordinates(Node_j,1))/2; %x-coordinate of middle of n element
    y_middle=(NodesCoordinates(Node_i,2)+NodesCoordinates(Node_j,2))/2; %y-coordinate of middle of n element
    text(x_middle,y_middle,element_id,'FontSize',11,'FontWeight','bold','HorizontalAlignment','center','VerticalAlignment','bottom','Color',[1 0 0]);
    switch ElementProperties(n,5) %Determine what kind of element it is
        case 2 % Beam o------- with hinge at start i (P2' type, hinge at start i)
            text(x_middle,y_middle,'o---','FontSize',12,'FontWeight','bold','HorizontalAlignment','center','VerticalAlignment','top','Color',[0 1 1]);
        case 3 % Beam -------o with hinge at end j (P2' type, hinge at end j)
            text(x_middle,y_middle,'---o','FontSize',12,'FontWeight','bold','HorizontalAlignment','center','VerticalAlignment','top','Color',[0 1 1]);
        case 4 % Beam o------o with hinges at both ends (P1 Type, hinges at start i and end j)
            text(x_middle,y_middle,'o---o','FontSize',12,'FontWeight','bold','HorizontalAlignment','center','VerticalAlignment','top','Color',[0 1 1]);
    end
end


%% Draw node constraints
for n=1:NumNodes; %Scan all nodes
    node_id=sprintf('  %i',n);
    text(NodesCoordinates(n,1),NodesCoordinates(n,2),node_id,'FontSize',12,'FontWeight','bold','HorizontalAlignment','left','Color',[0 0 1]);
    if BoundaryConditions(n,1)~=0 || BoundaryConditions(n,2)~=0 || BoundaryConditions(n,3)~=0
        for i=1:3
            if BoundaryConditions(n,i)==1
                    constraint=sprintf(' x ');
            else
                    constraint=sprintf(' o ');
            end
            switch i
                case 1
                    text(NodesCoordinates(n,1),NodesCoordinates(n,2),constraint,'FontSize',12,'FontWeight','bold','HorizontalAlignment','right','VerticalAlignment','top','Color',[0 1 0]);
                case 2
                    text(NodesCoordinates(n,1),NodesCoordinates(n,2),constraint,'FontSize',12,'FontWeight','bold','HorizontalAlignment','center','VerticalAlignment','top','Color',[0 1 0]);
                case 3
                    text(NodesCoordinates(n,1),NodesCoordinates(n,2),constraint,'FontSize',12,'FontWeight','bold','HorizontalAlignment','left','VerticalAlignment','top','Color',[0 1 0]);
            end
        end
    end
end


%% Draw labels, etc
grid on; %Draw grid
xlabel('x Coordinate','FontSize',12)
ylabel('y Coordinate','FontSize',12)

FigureTitle=['PFrameMatlab model geometry : ' InputFileName];

title(FigureTitle,'FontSize',12)
axis equal

% End of file -------------------------------------------------------------